/**
   @file main.c
   @brief Ejemplo básico de acceso a periférico mediante bibliotecas
   
   @author Equipo curso ARM Cortex-M http://armcortexm.blogs.upv.es
   @date 2013/04/18

*/

#include <stdint.h>     // definiciones estándar para los números enteros

#include "stm32f4xx_rcc.h"    // cabeceras proporcionadas por St para periféricos
#include "stm32f4xx_gpio.h"

void retardo(uint32_t cuenta);
void led_inicializar(void);
void led_on(void);
void led_off(void);

/*** programa principal ******************************************************/
int main (void) 
{
   
   led_inicializar();

   while (1) {
        led_on();
        retardo(1000000);
        led_off();
        retardo(1000000);
   }
      
   //return(0);
}


/*****************************************************************************/
/**
  * @brief  Preparación del pin donde está el LED azul, PD15
  * @param  Nada
  * @retval Nada
  */
void led_inicializar(void) 
{
   GPIO_InitTypeDef  GPIO_InitStructure;  // estructura donde se pone la configuración deseada

   RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE); // darle reloj al periférico, AHORA VIVE!
    
   GPIO_StructInit(&GPIO_InitStructure);   // establecer valores por defecto

   /* dar los detalles del puerto/pin */
   GPIO_InitStructure.GPIO_Pin   = GPIO_Pin_15;        // pin que desamos configurar
   GPIO_InitStructure.GPIO_Mode  = GPIO_Mode_OUT;      // lo vamos a usar como salida
   GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;      // queremos que sea push-pull
   GPIO_InitStructure.GPIO_Speed = GPIO_Speed_25MHz;   // frecuencia máxima para el puerto
   GPIO_InitStructure.GPIO_PuPd  = GPIO_PuPd_NOPULL;   // desactivar los pull-up, no hacen falta
   
   GPIO_Init(GPIOD, &GPIO_InitStructure);              // hacer efectiva configuración puerto
}


/*****************************************************************************/
/**
  * @brief  Encender el LED
  * @param  Nada
  * @retval Nada
  */
void led_on(void) 
{
    GPIO_SetBits(GPIOD, GPIO_Pin_15);     // poner a "1" la línea PD15
}


/*****************************************************************************/
/**
  * @brief  Apagar el LED
  * @param  Nada
  * @retval Nada
  */
void led_off(void) 
{
    GPIO_ResetBits(GPIOD, GPIO_Pin_15);     // poner a "0" la línea PD15
}

/*****************************************************************************/
/**
  * @brief  Funcion de retardo básica
  * @param  cuenta:el retardo a ojo
  * @retval Nada
  */
void retardo(uint32_t nCount)
{
  while(nCount--)
  {
  }
}

/*** Fin del archivo *********************************************************/

